#include <stdio.h>
#include <stdlib.h>
#include <usb.h>

#define FALSE   0
#define TRUE    1

#define SET_RATE            0x01
#define SET_DISPLAY_BUFFER  0x02
#define GET_DISPLAY_BUFFER  0x03

int main(int argc, char *argv[]) {
    struct usb_bus *bus;
    struct usb_device *dev;
    usb_dev_handle *udev;
    int dev_found, ret, rate;
    unsigned char buffer[8];
    
    if (argc != 2) {
        printf("Usage: %s <rate>\n", argv[0]);
        exit(-1);
    }
    rate = atoi(argv[1]);
    if ((rate < 0) || (rate > 255)) {
        printf("Illegal rate (%d) specified.\n", rate);
        exit(-1);
    }

    usb_init();

    usb_find_busses();
    usb_find_devices();

    udev = NULL;
    dev_found = FALSE;
    for (bus = usb_get_busses(); bus && !dev_found; bus = bus->next) {
        for (dev = bus->devices; dev && !dev_found; dev = dev->next) {
            if ((dev->descriptor.idVendor == 0x04D8) && (dev->descriptor.idProduct == 0x0004)) {
                dev_found = TRUE;
                udev = usb_open(dev);
            }
        }
    }
    if (!dev_found) {
        printf("No matching device found...\n");
    }
    if (udev) {
        ret = usb_control_msg(udev, 0x40, SET_RATE, rate, 0, buffer, 0, 100);
        if (ret < 0) {
            printf("Unable to send vendor request, ret = %d...\n", ret);
        }
        usb_close(udev);
    }
}
